@@ -3,13 +3,15 @@
  * See the COPYING file for licensing details.
  *
  * Copyright 2005 John Spray
+ * Copyright 2009 Jordan Mantha <jordan.mantha@gmail.com>
  */
 
 
 // For exit ()
 #include <stdlib.h>
 
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
+#include <glib.h>
 #include <glade/glade.h>
 #include <string.h>
 #include "droplist.h"
@@ -31,6 +33,8 @@ static struct {
 	GtkWidget *errorbarscheck;
 	GtkWidget *gridcheck;
 	GtkWidget *enhancedmodecheck;
+	GtkWidget *logscaleycheck;
+	GtkWidget *logscalexcheck;
 	GtkWidget *titleentry;
 	GtkWidget *xlabelentry;
 	GtkWidget *ylabelentry;
@@ -196,6 +200,9 @@ void droplist_init_gui ()
 	droplist.errorbarscheck = glade_xml_get_widget (xml, "ShowErrorbars");
 	droplist.gridcheck = glade_xml_get_widget (xml, "ShowGrid");
 	droplist.enhancedmodecheck = glade_xml_get_widget (xml, "EnableSuperSubScripts");
+	droplist.logscaleycheck = glade_xml_get_widget (xml, "EnableLogscaleY");
+	droplist.logscalexcheck = glade_xml_get_widget (xml, "EnableLogscaleX");
+	
 
 	droplist.xlabelentry = glade_xml_get_widget (xml, "XLabel");
 	droplist.ylabelentry = glade_xml_get_widget (xml, "YLabel");
@@ -369,6 +376,10 @@ void droplist_getdata (plotdata *data)
 		GTK_TOGGLE_BUTTON (droplist.gridcheck));
 	data->enhancedmode = gtk_toggle_button_get_active (
 		GTK_TOGGLE_BUTTON (droplist.enhancedmodecheck));
+	data->logscaley = gtk_toggle_button_get_active (
+		GTK_TOGGLE_BUTTON (droplist.logscaleycheck));
+	data->logscalex = gtk_toggle_button_get_active (
+		GTK_TOGGLE_BUTTON (droplist.logscalexcheck));
 
 	// Captions
 	data->xlabel = gtk_entry_get_text (GTK_ENTRY (droplist.xlabelentry));
@@ -607,31 +618,19 @@ void droplist_drag_data_received (GtkWidget *widget,
                                   guint time,
                                   gpointer user_data)
 {
-	GList *list = NULL;
-	GSList *file_list = NULL;
-	GList *p = NULL;
+gchar **uriList;
 
-	list = gnome_vfs_uri_list_parse (data->data);
-	p = list;
+uriList = g_uri_list_extract_uris (data->data);
 
-	while (p != NULL)
+for (int i = 0; uriList[i] != NULL; i++)
 	{
-		file_list = g_slist_prepend (file_list,
-			gnome_vfs_uri_to_string ((const GnomeVFSURI*)(p->data),
-			GNOME_VFS_URI_HIDE_NONE));
+	gchar *filename = g_filename_from_uri (uriList[i], NULL, NULL);
+	droplist_add_file (filename);
 
-		gchar *uripath = gnome_vfs_uri_to_string ((const GnomeVFSURI*)(p->data), 0);
-		gchar *filename = g_filename_from_uri (uripath, NULL, NULL);
-		droplist_add_file (filename);
-		g_free (filename);
-		g_free (uripath);
-
-		p = g_list_next (p);
+	g_free(filename);
 	}
 
-	gnome_vfs_uri_list_free (list);
-
-	file_list = g_slist_reverse (file_list);
+g_strfreev (uriList);
 }
 
 
@@ -746,7 +745,10 @@ void droplist_row_activated (GtkTreeView *treeview,
 	gtk_tree_model_get (model, &it, COL_PATH, &path, -1);
 	path = g_strdup_printf ("file://%s", path);
 
-	gnome_vfs_url_show (path);
+	/*
+	gnome_vfs_url_show(path); should get replaced with something like:
+	gtk_show_uri (NULL, path,gtk_get_current_event_time (), &error);
+	*/
 
 	g_free (path);
 }
